#
# Copyright (c) 2013-2018 Quarkslab.
# This file is part of IRMA project.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License in the top-level directory
# of this distribution and at:
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# No part of the project, including this file, may be copied,
# modified, propagated, or distributed except according to the
# terms contained in the LICENSE file.

from datetime import datetime

from irma.common.utils.utils import timestamp
from irma.common.plugins import PluginBase
from irma.common.plugins import FileDependency
from irma.common.plugin_result import PluginResult
from irma.common.base.utils import IrmaProbeType
from irma.common.plugins.exceptions import PluginLoadError


from configparser import ConfigParser
import os
import requests
import json
import time

# =====

class CuckooPlugin(PluginBase):
    web_url = None
    api_url = None
    timeout = None
    running_timeout = None
    delete_tasks = None


    class Cuckoo:
        ERROR = -1
        FAILURE = 0
        SUCCESS = 1


    # =================
    #  plugin metadata
    # =================
    _plugin_name_ = "Cuckoo"
    _plugin_display_name_ = "Cuckoo Sandbox"
    _plugin_author_ = "knaku"
    _plugin_version_ = "1.0.0"
    _plugin_category_ = "IrmaProbeType.external"
    _plugin_description_ = "Plugin to query Cuckoo Sandbox"
    _plugin_dependencies_ = [
        FileDependency(
            os.path.join(os.path.dirname(__file__), 'config.ini'),
            help='Make sure to rename/copy and configure the config file to your IP:PORT'
        ),
    ]
    _mimetype_regexp = None

    # =============
    #  constructor
    # =============

    def __init__(self):

        # load default configuration file
        config = ConfigParser()
        config.read(os.path.join(os.path.dirname(__file__), 'config.ini'))

        # override default values if specified
        if self.web_url is None:
            self.web_url = config.get('Cuckoo', 'web_url')

        if self.api_url is None:
            self.api_url = config.get('Cuckoo', 'api_url')

        if self.timeout is None:
            self.timeout = config.get('Cuckoo', 'timeout')

        if self.running_timeout is None:
            self.running_timeout = config.get('Cuckoo', 'running_timeout')

        if self.delete_tasks is None:
            self.delete_tasks = bool(config.get('Cuckoo', 'delete_tasks'))


    # =============
    #  processor
    # =============


    def get_file_report(self, filename):

        submit_task = self.api_url + 'tasks/create/file'
        get_report = selfapi_url + 'tasks/report/'
        view_status = self.api_url + 'tasks/view/'
        web_report_url = (
            '<a href="{web_url}/analysis/{{task_id}}/summary/" target="_blank">'
            'View the report in Cuckoo</a>'
        ).format(web_url=web_url)


        request = requests.post(submit_task, headers=HEADERS, files=files)  # submit a file for scanning

        # Wait for tasks to finish
        while task_done:
            status = requests.get(view_url + str(task_id)).json()

            if status['task']['status'] == 'reported':
                report = requests.get(report_url + str(task_id))
                #Cuckoo doesn't output the scored value, so there is no way to determine whether is it sage of not. Set to ERROR to catch a users attetion
                #when iplemented check report for answer, or use other returned values to decided whether safe or malicious
                results.status = self.Cuckoo.ERROR
                break


            elif status not in ['pending', 'processing', 'finished', 'completed', 'running']:
                results.status = self.Cuckoo.ERROR
                results.error = "Unkown status" + status
                break

            if status['task']['status'] != 'reported':
                time.sleep(15)

        return web_report_url


    def run(self, paths):

        results = PluginResult(name=type(self).plugin_display_name,
                               type=type(self).plugin_category,
                               version=None)

        try:
            started = timestamp(datetime.utcnow())
            response = self.get_file_report(paths)
            stopped = timestamp(datetime.utcnow())
            results.duration = stopped - started
            results.results = response
        except Exception as e:
            results.status = self.Cuckoo.ERROR
            results.results = str(e)

        return results

